@@ -35,6 +35,9 @@ now = now - timedelta(microseconds=now.microsecond)
 def callable_payload():
     print("From Callable")
 
+def callable_payload2():
+    print("From Callable for resting")
+
 at((now + timedelta(seconds=1)).time(), "Demo event", callable_payload)
 
 at((now + timedelta(seconds=3)).time(), "Demo event")
@@ -42,19 +45,22 @@ at((now + timedelta(seconds=3)).time(), "Demo event")
 cycle((now + timedelta(seconds=5)).time(), 
     (now + timedelta(seconds=20)).time(),
     "00:00:05",
-    "00:00:05", "Demo cycle")
+    "00:00:05",
+    "Demo cycle",
+    None,
+    payloads().use(callable_payload2))
 
 prompter.clear().useSwitcher().useConsole().useCallable()
 """
     click.echo("A demo schema:\n")
     click.echo("\n".join(map(lambda x: "    " + x,
-                        demo_schema.strip().splitlines())))
+                             demo_schema.strip().splitlines())))
 
     tt = SchemaBuilder()
 
     tt.load(demo_schema)
 
-    click.echo("Built timetable:\n")
+    click.echo("\nBuilt timetable:\n")
 
     sc = Scheduler()
 
